# my-happy-python-utils



## install
```shell
python3.7 -m pip install -U my-happy-python-utils

or

python3.7 -m pip install -i https://pypi.org/simple/ -U my-happy-python-utils

```

## uninstall
```shell
python3.7 -m pip uninstall my-happy-python-utils
```


## how to use
See the examples directory in the project.
